@@ -8,14 +8,14 @@ from django.conf import settings
 class PublisherBase(ABC):
 
     @abstractclassmethod
-    def publish(cls, topic_name, body):
+    def publish(cls, topic_name, body, delay):
         pass
 
 
 class Sqs(PublisherBase):
 
     @classmethod
-    def publish(cls, topic_name, body):
+    def publish(cls, topic_name, body, delay):
         message_attributes = {
             'routing_key': {
                 'StringValue': topic_name,
@@ -31,13 +31,19 @@ class Sqs(PublisherBase):
 class RabbitMQ(PublisherBase):
 
     @classmethod
-    def publish(cls, topic_name, body):
-        print(settings.RABBITMQ_URL)
+    def publish(cls, topic_name, body, delay):
         params = pika.URLParameters(settings.RABBITMQ_URL)
         connection = pika.BlockingConnection(params)
         channel = connection.channel()
-        channel.exchange_declare(exchange=topic_name, exchange_type='topic', durable=True)
-        channel.basic_publish(exchange=topic_name, routing_key=topic_name, body=json.dumps(body))
+        if delay:
+            channel.exchange_declare(exchange=topic_name, exchange_type='x-delayed-message',
+                                     arguments={'x-delayed-type': 'direct'})
+            properties = pika.BasicProperties(headers={'x-delay': delay})
+            channel.basic_publish(exchange=topic_name, routing_key=topic_name, properties=properties,
+                                  body=json.dumps(body))
+        else:
+            channel.exchange_declare(exchange=topic_name, exchange_type='topic', durable=True)
+            channel.basic_publish(exchange=topic_name, routing_key=topic_name, body=json.dumps(body))
 
 
 class Publisher:
@@ -45,10 +51,10 @@ class Publisher:
     RABBITMQ = 'RABBITMQ'
 
     @staticmethod
-    def publish(topic_name, body):
+    def publish(topic_name, body, delay=None):
         publishers = {
             Publisher.SQS: Sqs(),
             Publisher.RABBITMQ: RabbitMQ()
         }
         publisher = publishers[settings.BROKER_NAME]
-        publisher.publish(topic_name, body)
+        publisher.publish(topic_name, body, delay)
